@@ -16,22 +16,22 @@
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
-;; $Source: /home/gfe/src/ksh-mode/RCS/ksh-mode.el,v $ --  
+;; $Source: /usr/CVSroot/XEmacs/xemacs-packages/prog/prog-modes/ksh-mode.el,v $ --  
 ;;
 ;; LCD Archive Entry:
 ;; ksh-mode|Gary Ellison|gfe@interhack.net
 ;; |Mode for editing sh/ksh/bash scripts
-;; |$Date: 1999/04/29 21:41:38 $|$Revision: 2.12 $|~/modes/ksh-mode.el.Z|
+;; |$Date: 1999/11/27 16:26:01 $|$Revision: 1.3 $|~/modes/ksh-mode.el.Z|
 
 ;; Author: Gary Ellison <gfe@interhack.net>
 ;;                   Interhack Posse
 ;;
 ;; Maintainer: Gary Ellison <gfe@interhack.net>
 ;; Created: Fri Jun 19
-;; $Revision: 2.12 $
+;; $Revision: 1.3 $
 ;; Keywords: shell, korn, bourne, sh, ksh, bash
 ;;
-;; Delta On   $Date: 1999/04/29 21:41:38 $
+;; Delta On   $Date: 1999/11/27 16:26:01 $
 ;; Last Modified By: Gary Ellison
 ;; Status          : Highly Functional
 ;;
@@ -74,6 +74,9 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; HISTORY 
+;; 13-May-99            Gary Ellison
+;;    Removed some testing baggage which leaked into previous release.
+;;
 ;; 29-Apr-99            Gary Ellison
 ;;    I moved and forgot to submit a forwarding address to the codeoffice.
 ;;    Minor mucks with font-lock.
@@ -234,7 +237,7 @@
 ;;    Conception of this mode.
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(defconst ksh-mode-version "$Revision: 2.12 $"
+(defconst ksh-mode-version "$Revision: 1.3 $"
   "*Version numbers of this version of ksh-mode")
 
 ;;
@@ -490,11 +493,7 @@ while, for, until, and select")
     ()
   (setq ksh-mode-map (make-sparse-keymap))
   (define-key ksh-mode-map "\t"    'ksh-indent-command)
-;;  (define-key ksh-mode-map "\t"    'ksh-indent-line)
-  (if (fboundp 'backward-or-forward-delete-char)
-      ;; XEmacs
-      (define-key ksh-mode-map "\177" 'backward-or-forward-delete-char)
-    (define-key ksh-mode-map "\177"    'backward-delete-char-untabify))
+  (define-key ksh-mode-map "\t"    'ksh-indent-line)
   (define-key ksh-mode-map "\C-j"    'reindent-then-newline-and-indent)
   (define-key ksh-mode-map "\e\t"    'ksh-complete-symbol)
   (define-key ksh-mode-map "\C-c\t"    'ksh-completion-init-and-pickup)
@@ -503,7 +502,7 @@ while, for, until, and select")
 
 ;;;###autoload
 (defun ksh-mode ()
-  "ksh-mode $Revision: 2.12 $ - Major mode for editing (Bourne, Korn or Bourne again)
+  "ksh-mode $Revision: 1.3 $ - Major mode for editing (Bourne, Korn or Bourne again)
 shell scripts.
 Special key bindings and commands:
 \\{ksh-mode-map}
